@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['uattributes_0',['uAttributes',['../a00770.html#a257bd1afa651e50183767f438112e30d',1,'_oslVolumeInfo::uAttributes'],['../a00766.html#a40f4d1d56f02d357a7cd263defaa06a1',1,'_oslFileStatus::uAttributes']]],
+  ['uattributes_0',['uattributes',['../a00770.html#a257bd1afa651e50183767f438112e30d',1,'_oslVolumeInfo::uAttributes'],['../a00766.html#a40f4d1d56f02d357a7cd263defaa06a1',1,'_oslFileStatus::uAttributes']]],
   ['ufilesize_1',['uFileSize',['../a00766.html#a75ceaf2d09b3dba8ab6ebbcc07d2f721',1,'_oslFileStatus']]],
   ['ufreespace_2',['uFreeSpace',['../a00770.html#af0cde1f869fb488ada3e2b248a7035d3',1,'_oslVolumeInfo']]],
   ['uik_2eh_3',['uik.h',['../a00248.html',1,'']]],
@@ -37,7 +37,7 @@ var searchData=
   ['uno_5fenvcallee_34',['uno_EnvCallee',['../a00293.html#ab9b865bd93a54c6b944a0c2a7e56563b',1,'environment.h']]],
   ['uno_5fenvdcp_5fgetpurpose_35',['uno_EnvDcp_getPurpose',['../a00290.html#a9a0dde1b906397e5e6efbecf511e9b92',1,'EnvDcp.h']]],
   ['uno_5fenvdcp_5fgettypename_36',['uno_EnvDcp_getTypeName',['../a00290.html#a44057a45f74ce74fde1abdc6737f53a7',1,'EnvDcp.h']]],
-  ['uno_5fenvironment_37',['uno_Environment',['../a00431.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment:&#160;factory.hxx'],['../a00293.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment:&#160;environment.h']]],
+  ['uno_5fenvironment_37',['uno_environment',['../a00431.html#a74e26b81b7e694cdfdba825489dcb1cb',1,'uno_Environment:&#160;factory.hxx'],['../a00293.html#a0057727f6a3e4c9381f41d0d53f6bc20',1,'uno_Environment:&#160;environment.h']]],
   ['uno_5fenvironment_5fenter_38',['uno_Environment_enter',['../a00293.html#a10babae0f34bc1e243fd1ee0861345a8',1,'environment.h']]],
   ['uno_5fenvironment_5finvoke_39',['uno_Environment_invoke',['../a00293.html#a140e3f1812a48adf2a0132cc20dad79f',1,'environment.h']]],
   ['uno_5fenvironment_5finvoke_5fv_40',['uno_Environment_invoke_v',['../a00293.html#a265e36b8a54300e1115e912b9f6e709e',1,'environment.h']]],
@@ -58,7 +58,7 @@ var searchData=
   ['uno_5fgetregisteredenvironments_55',['uno_getRegisteredEnvironments',['../a00293.html#a63698ba5e3bc155159103464fc4fc0e0',1,'environment.h']]],
   ['uno_5finit_5fenvironment_56',['UNO_INIT_ENVIRONMENT',['../a00293.html#a11a567b305a6840caf5e4426bdc8801b',1,'environment.h']]],
   ['uno_5finitenvironmentfunc_57',['uno_initEnvironmentFunc',['../a00293.html#a65fa1b1ce1d750173fdeac329953240f',1,'environment.h']]],
-  ['uno_5finterface_58',['uno_Interface',['../a00284.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface:&#160;dispatcher.h'],['../a02525.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface:&#160;mapping.hxx']]],
+  ['uno_5finterface_58',['uno_interface',['../a00284.html#a01e8e71e2517bfaf724992d49a7319d2',1,'uno_Interface:&#160;dispatcher.h'],['../a02525.html#a5d48d6cca53bfac7c4e87cd815059a0e',1,'uno_Interface:&#160;mapping.hxx']]],
   ['uno_5flb_5fcli_59',['UNO_LB_CLI',['../a00278.html#a84d4660cf5829ea4cafdcc4b0eb959d8',1,'lbnames.h']]],
   ['uno_5flb_5fjava_60',['UNO_LB_JAVA',['../a00278.html#a309a16dcace607fe4cfc5e3a00c8e003',1,'lbnames.h']]],
   ['uno_5flb_5funo_61',['UNO_LB_UNO',['../a00278.html#accb8e197166b7c7ff294fbe084ae3cc8',1,'lbnames.h']]],
@@ -115,9 +115,9 @@ var searchData=
   ['unotype_112',['UnoType',['../a01014.html',1,'cppu']]],
   ['unotype_2ehxx_113',['unotype.hxx',['../a00320.html',1,'']]],
   ['unotype_5fnoacquire_114',['UnoType_NoAcquire',['../a00536.html#a72b6c10d5cb770d942e2156c1b3160f9',1,'com::sun::star::uno']]],
-  ['unourl_115',['UnoUrl',['../a01942.html',1,'cppu::UnoUrl'],['../a01942.html#a23b5e876eecd29a9f1e5161b1e3a8407',1,'cppu::UnoUrl::UnoUrl(UnoUrl const &amp;rOther)'],['../a01942.html#af74f9f63ba57a8664ce63da416fa7b83',1,'cppu::UnoUrl::UnoUrl(rtl::OUString const &amp;rUrl)']]],
+  ['unourl_115',['unourl',['../a01942.html#a23b5e876eecd29a9f1e5161b1e3a8407',1,'cppu::UnoUrl::UnoUrl()'],['../a01942.html',1,'cppu::UnoUrl'],['../a01942.html#af74f9f63ba57a8664ce63da416fa7b83',1,'cppu::UnoUrl::UnoUrl()']]],
   ['unourl_2ehxx_116',['unourl.hxx',['../a00386.html',1,'']]],
-  ['unourldescriptor_117',['UnoUrlDescriptor',['../a01938.html',1,'cppu::UnoUrlDescriptor'],['../a01938.html#a35adf9b2722dcfe5dd0cf0a0588e2ac2',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(rtl::OUString const &amp;rDescriptor)'],['../a01938.html#adc91019dd09706a1e8a083244967f78d',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(UnoUrlDescriptor const &amp;rOther)']]],
+  ['unourldescriptor_117',['unourldescriptor',['../a01938.html',1,'cppu::UnoUrlDescriptor'],['../a01938.html#a35adf9b2722dcfe5dd0cf0a0588e2ac2',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(rtl::OUString const &amp;rDescriptor)'],['../a01938.html#adc91019dd09706a1e8a083244967f78d',1,'cppu::UnoUrlDescriptor::UnoUrlDescriptor(UnoUrlDescriptor const &amp;rOther)']]],
   ['unusedsince_118',['unusedSince',['../a00742.html#a2c27af5fa12d01c9c39f80eb0b2c36c3',1,'_rtl_StandardModuleCount']]],
   ['uri_119',['Uri',['../a00746.html',1,'rtl']]],
   ['uri_2eh_120',['uri.h',['../a00140.html',1,'']]],
@@ -133,9 +133,9 @@ var searchData=
   ['ustring_2eh_130',['ustring.h',['../a00065.html',1,'']]],
   ['ustring_2ehxx_131',['ustring.hxx',['../a00152.html',1,'']]],
   ['ustrlinktargeturl_132',['ustrLinkTargetURL',['../a00766.html#a2de4bbf56cecf5435fe11dea696092ce',1,'_oslFileStatus']]],
-  ['ustructsize_133',['uStructSize',['../a00770.html#ae7df80711543ea419945503a03d227fe',1,'_oslVolumeInfo::uStructSize'],['../a00766.html#a9dd21f3d1a624da3b85b65caba4282ac',1,'_oslFileStatus::uStructSize']]],
+  ['ustructsize_133',['ustructsize',['../a00770.html#ae7df80711543ea419945503a03d227fe',1,'_oslVolumeInfo::uStructSize'],['../a00766.html#a9dd21f3d1a624da3b85b65caba4282ac',1,'_oslFileStatus::uStructSize']]],
   ['utotalspace_134',['uTotalSpace',['../a00770.html#a82cd611883c8c6187e4cc090e37b5137',1,'_oslVolumeInfo']]],
   ['uuid_2eh_135',['uuid.h',['../a00098.html',1,'']]],
   ['uusedspace_136',['uUsedSpace',['../a00770.html#a4dcd71fa9f7fd7f2c9924651b1f9d1e1',1,'_oslVolumeInfo']]],
-  ['uvalidfields_137',['uValidFields',['../a00770.html#a177b8213c8e157fe61ded493f8d40e87',1,'_oslVolumeInfo::uValidFields'],['../a00766.html#a1ea0b2e33b86e8cb9680c16c9f0611da',1,'_oslFileStatus::uValidFields']]]
+  ['uvalidfields_137',['uvalidfields',['../a00770.html#a177b8213c8e157fe61ded493f8d40e87',1,'_oslVolumeInfo::uValidFields'],['../a00766.html#a1ea0b2e33b86e8cb9680c16c9f0611da',1,'_oslFileStatus::uValidFields']]]
 ];
